@@ -19,6 +19,8 @@
 
 #include <algorithm>
 
+K_PLUGIN_CLASS_WITH_JSON(KScreenApplet, "metadata.json")
+
 KScreenApplet::KScreenApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Applet(parent, data, args)
 {
@@ -89,8 +91,6 @@ QVariant KScreenApplet::availableActions()
     return QVariant::fromValue(ret);
 }
 
-K_PLUGIN_CLASS(KScreenApplet)
-
 #include "kscreenapplet.moc"
 
 #include "moc_kscreenapplet.cpp"
